@@ -1,6 +1,6 @@
 use super::{
     visibility_blocking, CommandBlocking, CommandInfo, Component,
-    DrawableComponent,
+    DrawableComponent, EventState,
 };
 use crate::{
     components::ScrollType,
@@ -129,7 +129,8 @@ impl Component for BranchListComponent {
                 strings::commands::select_branch_popup(
                     &self.key_config,
                 ),
-                !self.selection_is_cur_branch(),
+                !self.selection_is_cur_branch()
+                    && self.valid_selection(),
                 true,
             ));
 
@@ -160,31 +161,43 @@ impl Component for BranchListComponent {
         visibility_blocking(self)
     }
 
-    fn event(&mut self, ev: Event) -> Result<bool> {
+    fn event(&mut self, ev: Event) -> Result<EventState> {
         if self.visible {
             if let Event::Key(e) = ev {
                 if e == self.key_config.exit_popup {
                     self.hide()
                 } else if e == self.key_config.move_down {
-                    return self.move_selection(ScrollType::Up);
+                    return self
+                        .move_selection(ScrollType::Up)
+                        .map(Into::into);
                 } else if e == self.key_config.move_up {
-                    return self.move_selection(ScrollType::Down);
+                    return self
+                        .move_selection(ScrollType::Down)
+                        .map(Into::into);
                 } else if e == self.key_config.page_down {
-                    return self.move_selection(ScrollType::PageDown);
+                    return self
+                        .move_selection(ScrollType::PageDown)
+                        .map(Into::into);
                 } else if e == self.key_config.page_up {
-                    return self.move_selection(ScrollType::PageUp);
+                    return self
+                        .move_selection(ScrollType::PageUp)
+                        .map(Into::into);
                 } else if e == self.key_config.enter {
                     try_or_popup!(
                         self,
                         "switch branch error:",
                         self.switch_to_selected_branch()
                     );
-                } else if e == self.key_config.create_branch {
+                } else if e == self.key_config.create_branch
+                    && self.local
+                {
                     self.queue
                         .borrow_mut()
                         .push_back(InternalEvent::CreateBranch);
                     self.hide();
-                } else if e == self.key_config.rename_branch {
+                } else if e == self.key_config.rename_branch
+                    && self.valid_selection()
+                {
                     let cur_branch =
                         &self.branches[self.selection as usize];
                     self.queue.borrow_mut().push_back(
@@ -197,6 +210,7 @@ impl Component for BranchListComponent {
                     self.update_branches()?;
                 } else if e == self.key_config.delete_branch
                     && !self.selection_is_cur_branch()
+                    && self.valid_selection()
                 {
                     self.queue.borrow_mut().push_back(
                         InternalEvent::ConfirmAction(
@@ -214,9 +228,9 @@ impl Component for BranchListComponent {
                 }
             }
 
-            Ok(true)
+            Ok(EventState::Consumed)
         } else {
-            Ok(false)
+            Ok(EventState::NotConsumed)
         }
     }
 
@@ -276,6 +290,10 @@ impl BranchListComponent {
         Ok(())
     }
 
+    fn valid_selection(&self) -> bool {
+        !self.branches.is_empty()
+    }
+
     fn selection_is_cur_branch(&self) -> bool {
         self.branches
             .iter()
@@ -433,6 +451,10 @@ impl BranchListComponent {
 
     ///
     fn switch_to_selected_branch(&mut self) -> Result<()> {
+        if !self.valid_selection() {
+            anyhow::bail!("no valid branch selected");
+        }
+
         if self.local {
             checkout_branch(
                 asyncgit::CWD,
@@ -483,6 +505,7 @@ impl BranchListComponent {
         r: Rect,
     ) -> Result<()> {
         let height_in_lines = r.height as usize;
+        self.current_height.set(height_in_lines.try_into()?);
 
         self.scroll_top.set(calc_scroll_top(
             self.scroll_top.get(),
@@ -502,17 +525,17 @@ impl BranchListComponent {
 
         let mut r = r;
         r.width += 1;
+        r.height += 2;
+        r.y = r.y.saturating_sub(1);
 
         ui::draw_scrollbar(
             f,
             r,
             &self.theme,
-            self.branches.len(),
+            self.branches.len().saturating_sub(height_in_lines),
             self.scroll_top.get(),
         );
 
-        self.current_height.set(height_in_lines.try_into()?);
-
         Ok(())
     }
 }
