@@ -1,7 +1,7 @@
 use super::{
     textinput::TextInputComponent, visibility_blocking,
     CommandBlocking, CommandInfo, Component, DrawableComponent,
-    ExternalEditorComponent,
+    EventState, ExternalEditorComponent,
 };
 use crate::{
     get_app_config_path,
@@ -12,22 +12,30 @@ use crate::{
 };
 use anyhow::Result;
 use asyncgit::{
-    sync::{self, CommitId, HookResult},
+    cached,
+    sync::{self, utils::get_config_string, CommitId, HookResult},
     CWD,
 };
 use crossterm::event::Event;
 use std::{
-    fs::File,
+    fs::{read_to_string, File},
     io::{Read, Write},
     path::PathBuf,
 };
-use tui::{backend::Backend, layout::Rect, Frame};
+use tui::{
+    backend::Backend,
+    layout::{Alignment, Rect},
+    widgets::Paragraph,
+    Frame,
+};
 
 pub struct CommitComponent {
     input: TextInputComponent,
     amend: Option<CommitId>,
     queue: Queue,
     key_config: SharedKeyConfig,
+    git_branch_name: cached::BranchName,
+    commit_template: Option<String>,
 }
 
 impl DrawableComponent for CommitComponent {
@@ -36,7 +44,10 @@ impl DrawableComponent for CommitComponent {
         f: &mut Frame<B>,
         rect: Rect,
     ) -> Result<()> {
-        self.input.draw(f, rect)?;
+        if self.is_visible() {
+            self.input.draw(f, rect)?;
+            self.draw_branch_name(f);
+        }
 
         Ok(())
     }
@@ -75,10 +86,10 @@ impl Component for CommitComponent {
         visibility_blocking(self)
     }
 
-    fn event(&mut self, ev: Event) -> Result<bool> {
+    fn event(&mut self, ev: Event) -> Result<EventState> {
         if self.is_visible() {
-            if self.input.event(ev)? {
-                return Ok(true);
+            if self.input.event(ev)?.is_consumed() {
+                return Ok(EventState::Consumed);
             }
 
             if let Event::Key(e) = ev {
@@ -96,11 +107,11 @@ impl Component for CommitComponent {
                 } else {
                 }
                 // stop key event propagation
-                return Ok(true);
+                return Ok(EventState::Consumed);
             }
         }
 
-        Ok(false)
+        Ok(EventState::NotConsumed)
     }
 
     fn is_visible(&self) -> bool {
@@ -112,11 +123,26 @@ impl Component for CommitComponent {
     }
 
     fn show(&mut self) -> Result<()> {
+        if self.amend.is_some() {
+            self.input.clear();
+        }
         self.amend = None;
 
-        self.input.clear();
         self.input
             .set_title(strings::commit_title(&self.key_config));
+
+        self.commit_template =
+            get_config_string(CWD, "commit.template")
+                .ok()
+                .flatten()
+                .and_then(|path| read_to_string(path).ok());
+
+        if self.is_empty() {
+            if let Some(s) = &self.commit_template {
+                self.input.set_text(s.clone());
+            }
+        }
+
         self.input.show()?;
 
         Ok(())
@@ -138,8 +164,34 @@ impl CommitComponent {
                 key_config.clone(),
                 "",
                 &strings::commit_msg(&key_config),
+                true,
             ),
             key_config,
+            git_branch_name: cached::BranchName::new(CWD),
+            commit_template: None,
+        }
+    }
+
+    ///
+    pub fn update(&mut self) -> Result<()> {
+        self.git_branch_name.lookup().map(Some).unwrap_or(None);
+
+        Ok(())
+    }
+
+    fn draw_branch_name<B: Backend>(&self, f: &mut Frame<B>) {
+        if let Some(name) = self.git_branch_name.last() {
+            let w = Paragraph::new(format!("{{{}}}", name))
+                .alignment(Alignment::Right);
+
+            let rect = {
+                let mut rect = self.input.get_area();
+                rect.height = 1;
+                rect.width = rect.width.saturating_sub(1);
+                rect
+            };
+
+            f.render_widget(w, rect);
         }
     }
 
@@ -190,7 +242,9 @@ impl CommitComponent {
     }
 
     fn commit(&mut self) -> Result<()> {
-        self.commit_msg(self.input.get_text().clone())
+        let msg = self.input.get_text().clone();
+        self.input.clear();
+        self.commit_msg(msg)
     }
 
     fn commit_msg(&mut self, msg: String) -> Result<()> {
@@ -253,13 +307,22 @@ impl CommitComponent {
     }
 
     fn can_commit(&self) -> bool {
-        !self.input.get_text().is_empty()
+        !self.is_empty() && self.is_changed()
     }
 
     fn can_amend(&self) -> bool {
         self.amend.is_none()
             && sync::get_head(CWD).is_ok()
-            && self.input.get_text().is_empty()
+            && (self.is_empty() || !self.is_changed())
+    }
+
+    fn is_empty(&self) -> bool {
+        self.input.get_text().is_empty()
+    }
+
+    fn is_changed(&self) -> bool {
+        Some(self.input.get_text().trim())
+            != self.commit_template.as_ref().map(|s| s.trim())
     }
 
     fn amend(&mut self) -> Result<()> {
