@@ -2,7 +2,7 @@ mod details;
 
 use super::{
     command_pump, event_pump, CommandBlocking, CommandInfo,
-    Component, DrawableComponent, FileTreeComponent,
+    Component, DrawableComponent, EventState, FileTreeComponent,
 };
 use crate::{
     accessors, keys::SharedKeyConfig, queue::Queue, strings,
@@ -115,12 +115,20 @@ impl DrawableComponent for CommitDetailsComponent {
         f: &mut Frame<B>,
         rect: Rect,
     ) -> Result<()> {
+        let percentages = if self.file_tree.focused() {
+            (40, 60)
+        } else if self.details.focused() {
+            (60, 40)
+        } else {
+            (40, 60)
+        };
+
         let chunks = Layout::default()
             .direction(Direction::Vertical)
             .constraints(
                 [
-                    Constraint::Percentage(60),
-                    Constraint::Percentage(40),
+                    Constraint::Percentage(percentages.0),
+                    Constraint::Percentage(percentages.1),
                 ]
                 .as_ref(),
             )
@@ -150,9 +158,11 @@ impl Component for CommitDetailsComponent {
         CommandBlocking::PassingOn
     }
 
-    fn event(&mut self, ev: Event) -> Result<bool> {
-        if event_pump(ev, self.components_mut().as_mut_slice())? {
-            return Ok(true);
+    fn event(&mut self, ev: Event) -> Result<EventState> {
+        if event_pump(ev, self.components_mut().as_mut_slice())?
+            .is_consumed()
+        {
+            return Ok(EventState::Consumed);
         }
 
         if self.focused() {
@@ -162,20 +172,20 @@ impl Component for CommitDetailsComponent {
                 {
                     self.details.focus(false);
                     self.file_tree.focus(true);
-                    Ok(true)
+                    Ok(EventState::Consumed)
                 } else if e == self.key_config.focus_above
                     && self.file_tree.focused()
                 {
                     self.file_tree.focus(false);
                     self.details.focus(true);
-                    Ok(true)
+                    Ok(EventState::Consumed)
                 } else {
-                    Ok(false)
+                    Ok(EventState::NotConsumed)
                 };
             }
         }
 
-        Ok(false)
+        Ok(EventState::NotConsumed)
     }
 
     fn is_visible(&self) -> bool {
