@@ -1,7 +1,7 @@
 use super::{
     command_pump, event_pump, visibility_blocking, CommandBlocking,
     CommandInfo, CommitDetailsComponent, Component, DiffComponent,
-    DrawableComponent,
+    DrawableComponent, EventState,
 };
 use crate::{
     accessors, keys::SharedKeyConfig, queue::Queue, strings,
@@ -103,10 +103,12 @@ impl Component for InspectCommitComponent {
         visibility_blocking(self)
     }
 
-    fn event(&mut self, ev: Event) -> Result<bool> {
+    fn event(&mut self, ev: Event) -> Result<EventState> {
         if self.is_visible() {
-            if event_pump(ev, self.components_mut().as_mut_slice())? {
-                return Ok(true);
+            if event_pump(ev, self.components_mut().as_mut_slice())?
+                .is_consumed()
+            {
+                return Ok(EventState::Consumed);
             }
 
             if let Event::Key(e) = ev {
@@ -126,12 +128,11 @@ impl Component for InspectCommitComponent {
                     self.hide();
                 }
 
-                // stop key event propagation
-                return Ok(true);
+                return Ok(EventState::Consumed);
             }
         }
 
-        Ok(false)
+        Ok(EventState::NotConsumed)
     }
 
     fn is_visible(&self) -> bool {
