@@ -1,6 +1,7 @@
 use super::{
     textinput::TextInputComponent, visibility_blocking,
     CommandBlocking, CommandInfo, Component, DrawableComponent,
+    EventState,
 };
 use crate::{
     keys::SharedKeyConfig,
@@ -54,10 +55,10 @@ impl Component for StashMsgComponent {
         visibility_blocking(self)
     }
 
-    fn event(&mut self, ev: Event) -> Result<bool> {
+    fn event(&mut self, ev: Event) -> Result<EventState> {
         if self.is_visible() {
-            if self.input.event(ev)? {
-                return Ok(true);
+            if self.input.event(ev)?.is_consumed() {
+                return Ok(EventState::Consumed);
             }
 
             if let Event::Key(e) = ev {
@@ -100,10 +101,10 @@ impl Component for StashMsgComponent {
                 }
 
                 // stop key event propagation
-                return Ok(true);
+                return Ok(EventState::Consumed);
             }
         }
-        Ok(false)
+        Ok(EventState::NotConsumed)
     }
 
     fn is_visible(&self) -> bool {
@@ -136,6 +137,7 @@ impl StashMsgComponent {
                 key_config.clone(),
                 &strings::stash_popup_title(&key_config),
                 &strings::stash_popup_msg(&key_config),
+                true,
             ),
             key_config,
         }
