@@ -1,7 +1,8 @@
 use crate::keys::SharedKeyConfig;
 
 pub mod order {
-    pub static NAV: i8 = 1;
+    pub static NAV: i8 = 2;
+    pub static RARE_ACTION: i8 = 1;
 }
 
 pub static PUSH_POPUP_MSG: &str = "Push";
@@ -170,6 +171,9 @@ pub fn confirm_msg_force_push(
 pub fn log_title(_key_config: &SharedKeyConfig) -> String {
     "Commit".to_string()
 }
+pub fn blame_title(_key_config: &SharedKeyConfig) -> String {
+    "Blame".to_string()
+}
 pub fn tag_commit_popup_title(
     _key_config: &SharedKeyConfig,
 ) -> String {
@@ -582,7 +586,7 @@ pub mod commands {
     pub fn edit_item(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
-                "Edit Item [{}]",
+                "Edit [{}]",
                 key_config.get_hint(key_config.edit_file),
             ),
             "edit the currently selected file in an external editor",
@@ -592,7 +596,7 @@ pub mod commands {
     pub fn stage_item(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
-                "Stage Item [{}]",
+                "Stage [{}]",
                 key_config.get_hint(key_config.enter),
             ),
             "stage currently selected file or entire path",
@@ -612,7 +616,7 @@ pub mod commands {
     pub fn unstage_item(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
-                "Unstage Item [{}]",
+                "Unstage [{}]",
                 key_config.get_hint(key_config.enter),
             ),
             "unstage currently selected file or entire path",
@@ -632,7 +636,7 @@ pub mod commands {
     pub fn reset_item(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
-                "Reset Item [{}]",
+                "Reset [{}]",
                 key_config.get_hint(key_config.status_reset_item),
             ),
             "revert changes in selected file or entire path",
@@ -817,6 +821,16 @@ pub mod commands {
             CMD_GROUP_LOG,
         )
     }
+    pub fn blame_file(key_config: &SharedKeyConfig) -> CommandText {
+        CommandText::new(
+            format!(
+                "Blame [{}]",
+                key_config.get_hint(key_config.blame),
+            ),
+            "open blame view of selected file",
+            CMD_GROUP_LOG,
+        )
+    }
     pub fn log_tag_commit(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
