@@ -2,7 +2,7 @@ use crate::{
     components::{
         visibility_blocking, CommandBlocking, CommandInfo,
         CommitDetailsComponent, CommitList, Component,
-        DrawableComponent,
+        DrawableComponent, EventState,
     },
     keys::SharedKeyConfig,
     queue::{InternalEvent, Queue},
@@ -77,7 +77,7 @@ impl Revlog {
 
     ///
     pub fn update(&mut self) -> Result<()> {
-        if self.visible {
+        if self.is_visible() {
             let log_changed =
                 self.git_log.fetch()? == FetchStatus::Started;
 
@@ -197,41 +197,41 @@ impl DrawableComponent for Revlog {
 }
 
 impl Component for Revlog {
-    fn event(&mut self, ev: Event) -> Result<bool> {
+    fn event(&mut self, ev: Event) -> Result<EventState> {
         if self.visible {
             let event_used = self.list.event(ev)?;
 
-            if event_used {
+            if event_used.is_consumed() {
                 self.update()?;
-                return Ok(true);
+                return Ok(EventState::Consumed);
             } else if let Event::Key(k) = ev {
                 if k == self.key_config.enter {
                     self.commit_details.toggle_visible()?;
                     self.update()?;
-                    return Ok(true);
+                    return Ok(EventState::Consumed);
                 } else if k == self.key_config.copy {
                     self.copy_commit_hash()?;
-                    return Ok(true);
+                    return Ok(EventState::Consumed);
                 } else if k == self.key_config.push {
                     self.queue
                         .borrow_mut()
                         .push_back(InternalEvent::PushTags);
-                    return Ok(true);
+                    return Ok(EventState::Consumed);
                 } else if k == self.key_config.log_tag_commit {
                     return self.selected_commit().map_or(
-                        Ok(false),
+                        Ok(EventState::NotConsumed),
                         |id| {
                             self.queue.borrow_mut().push_back(
                                 InternalEvent::TagCommit(id),
                             );
-                            Ok(true)
+                            Ok(EventState::Consumed)
                         },
                     );
                 } else if k == self.key_config.focus_right
                     && self.commit_details.is_visible()
                 {
                     return self.selected_commit().map_or(
-                        Ok(false),
+                        Ok(EventState::NotConsumed),
                         |id| {
                             self.queue.borrow_mut().push_back(
                                 InternalEvent::InspectCommit(
@@ -241,19 +241,19 @@ impl Component for Revlog {
                                     )),
                                 ),
                             );
-                            Ok(true)
+                            Ok(EventState::Consumed)
                         },
                     );
                 } else if k == self.key_config.select_branch {
                     self.queue
                         .borrow_mut()
                         .push_back(InternalEvent::SelectBranch);
-                    return Ok(true);
+                    return Ok(EventState::Consumed);
                 }
             }
         }
 
-        Ok(false)
+        Ok(EventState::NotConsumed)
     }
 
     fn commands(
